#include <stdio.h>
#include <assert.h>
#include <string.h>
#include <stdlib.h>
#include <ctype.h>

class Reader
{
protected:
	FILE *f;
	int putBackCh;
public:
	Reader(FILE *F) : putBackCh(-1), f(F) { assert(f); }
	~Reader() { if (f) fclose(f); }
	void PutBack(char ch) { assert(putBackCh < 0); putBackCh = ch; }
	int GetCh() {
		if (putBackCh >= 0) { int ch = putBackCh; putBackCh = -1; return ch; }
		else { /*printf("!");*/ return fgetc(f); }}
	bool SkipWs(int& ch) { bool any = false; for ( ; ; ) {
		ch = GetCh();
//printf("<%d; %d>", any, ch);
		if (ch == EOF) return any;
		else if (! (isspace(ch) || ch == '\xa' || ch == '\xd')) { PutBack(ch); return any; }
		else any = true; } }
	bool SkipSpaces(int& ch) { bool any = false; for ( ; ; ) {
		ch = GetCh();
		if (ch == EOF) return any;
		else if (! (isspace(ch) && ch != '\xa' && ch != '\xd')) { PutBack(ch); return any; }
		else any = true; } }
	bool ReadInt(int& i, FILE *fRept, const int lineNo, const char *cesa);
	bool ReadString(char *dest, int maxChars, const char* extraStopChars); // stop at space or extraStopChars
	bool AtEof() { int ch = GetCh(); if (ch < 0) return true; else { PutBack(ch); return false; }}
	bool AtEol() { int ch = GetCh(); bool b = (ch == '\xa' || ch == '\xd');
		if (ch >= 0) PutBack(ch);
		return b; }
	bool ReadLn() {
		int ch = GetCh(); if (ch < 0) return false;
		if (ch == '\xa') return true;
		if (ch == '\xd') {
			ch = GetCh();
			if (ch >= 0 && ch != '\xa') PutBack(ch);
			return true; }
		PutBack(ch); return false; }
	void ReadLnA() { bool ok = ReadLn(); assert(ok); }
};

bool Reader::ReadString(char *dest, int maxChars, const char* extraStopChars)
{
	int nRead = 0;
	for ( ; ; )
	{
		int ch = GetCh();
		if (ch < 0 || isspace(ch) || strchr(extraStopChars, ch)) { dest[nRead] = 0; if (ch > 0) PutBack(ch); return true; }
		if (nRead == maxChars) { dest[nRead] = 0; return false; }
		dest[nRead++] = char(ch);
	}
}

bool Reader::ReadInt(int& i, FILE *fRept, const int lineNo, const char *cesa)
{
	i = 0;
	int nDigits = 0;
	bool negative = false;
	{int ch = GetCh(); if (ch == '-') negative = true; else PutBack(ch);}
	for ( ; ; )
	{
		int ch = GetCh();
		if (ch < 0) { if (nDigits <= 0) { fprintf(fRept, "Napaka pri branju %s v %d. vrstici.  Pricakoval bi stevilo, nasel sem EOF.\n", cesa, lineNo); return false; }
			else return true; }
		if (ch < int('0') || ch > int('9')) { PutBack(ch);
			if (nDigits <= 0) { fprintf(fRept, "Napaka pri branju %s v %d. vrstici.  Pricakoval bi stevilo, nasel sem znak 0x%02x.\n", cesa, lineNo, int(ch)); return false; }
			else return true; }
		// 2^31 = 2147483648
		//printf("i = %d\n", i);
		if (i > 214748364) { fprintf(fRept, "Napaka pri branju %s v %d. vrstici.  Stevilo je preveliko (overflow).\n", cesa, lineNo); return false; }
		if (i < -214748364) { fprintf(fRept, "Napaka pri branju %s v %d. vrstici.  Stevilo je premajhno (underflow).\n", cesa, lineNo); return false; }
		/*
		int j = 2147483647 - i, d = int(ch - '0');
		//printf("i = %d, j = %d, d = %d\n", i, j, d);
		if (j < d) { fprintf(fRept, "%d. stevilo je preveliko (overflow).\n", katero); return false; }
		*/
		int d = int(ch - '0');
		if (i == 214748364 && d > 7) { fprintf(fRept, "Napaka pri branju %s v %d. vrstici.  Stevilo je preveliko (overflow).\n", cesa, lineNo); return false; }
		if (i == -214748364 && d > 8) { fprintf(fRept, "Napaka pri branju %s v %d. vrstici.  Stevilo je premajhno (underflow).\n", cesa, lineNo); return false; }
		i *= 10;
		if (negative) i -= d; else i += d;
		nDigits++;
	}
}


// > 1 --> error
// <= 0 --> OK (# points = return value + 10)
//
bool Test(const char* fnIn, const char* fnOut, const char* fnRept, const char* fnOrigOut, int& nPoints)
{
	nPoints = 0;
	// Read the input file.
	FILE *fIn = fopen(fnIn, "rt"); assert(fIn);
	enum { MaxN = 30 };
	int n, dxOk[MaxN], dyOk[MaxN]; 
	{int ok = fscanf(fIn, "%d", &n); assert(ok == 1); assert(0 < n && n <= MaxN);}
	fclose(fIn);
	// Read the best solution from the original output file.
	FILE *fOrigOut = fopen(fnOrigOut, "rt"); assert(fOrigOut);
	{for (int i = 0; i < n; i++) {
		int ok = fscanf(fOrigOut, "%d %d\n", &(dxOk[i]), &(dyOk[i])); assert(ok == 2); 
		assert(-3 <= dxOk[i] && dxOk[i] <= 3 && -3 <= dyOk[i] && dyOk[i] <= 3); }}
	fclose(fOrigOut);
	// Read the output file.
	FILE *fRept = fopen(fnRept, "wt"); assert(fRept);
	FILE *fOut = fopen(fnOut, "rb"); if (! fOut) { fprintf(fRept, "Ne morem odpreti izhodne datoteke \"%s\".\n", fnOut ? fnOut : "\0"); fclose(fRept); return false; }
	Reader reader(fOut);
	int nOk = 0, dummy;
	{for (int i = 0; i < n; i++)
	{
		int dx, dy;
		reader.SkipSpaces(dummy); 
		char buf[100]; sprintf(buf, "premika v smeri X pri %d. paru slik", i + 1);
		if (! reader.ReadInt(dx, fRept, i + 1, buf)) { fclose(fRept); return false; }
		if (dx < -3 || dx > 3) { fprintf(fRept, "Premik v smeri X pri %d. paru slik je %d, moral pa bi biti z intervala -3..3.\n", i + 1, dx); fclose(fRept); return false; }
		reader.SkipSpaces(dummy); 
		sprintf(buf, "premika v smeri Y pri %d. paru slik", i + 1);
		if (! reader.ReadInt(dy, fRept, i + 1, buf)) { fclose(fRept); return false; }
		if (dy < -3 || dy > 3) { fprintf(fRept, "Premik v smeri Y pri %d. paru slik je %d, moral pa bi biti z intervala -3..3.\n", i + 1, dx); fclose(fRept); return false; }
		if (dx == dxOk[i] && dy == dyOk[i]) nOk++;
		reader.SkipSpaces(dummy); 
		if (! reader.AtEol()) { fprintf(fRept, "Napaka v izhodni datoteki: v %d. vrstici so za obema premikoma se neki drugi znaki.\n", i + 1); fclose(fRept); return false; }
		reader.ReadLn();
	}}
	reader.SkipWs(dummy); if (! reader.AtEof()) { fprintf(fRept, "Napaka v izhodni datoteki: za vsemi premiki so se neki drugi znaki.\n"); fclose(fRept); return false; }
	//
	nPoints = (nOk * 10) / n;
	if (n == nOk) fprintf(fRept, "OK, vsi odgovori so pravilni (10/10).\n"); 
	else if (nOk == 0) fprintf(fRept, "Izhodna datoteka je pravilno oblikovana, vendar so vsi odgovori napacni (0 tock).\n");
	else fprintf(fRept, "Izhodna datoteka je pravilno oblikovana.  Nekateri odgovori so pravilni, nekateri napacni (%d/10 tock).\n", nPoints);
	fclose(fRept);
	return true;
}

int main(int argc, char** argv)
{
	assert(argc == 5);
	int nPoints = 0;
	bool ok = Test(argv[1], argv[2], argv[3], argv[4], nPoints);
	if (! ok) return -10; else return nPoints - 10;
}
